==> haskell-authenticate-1.3.3-21-armv7h.pkg.tar.xz: usr/share/haskell/haskell-authenticate/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.3
id: authenticate-1.3.3-0af1b89fe7385b681d2d488a8f776d68
key: authe_CoNMfqHQ2HAF0iNys4hCqM
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
exposed-modules:
    Web.Authenticate.Rpxnow Web.Authenticate.OpenId
    Web.Authenticate.BrowserId Web.Authenticate.OpenId.Providers
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
hs-libraries: HSauthenticate-1.3.3-CoNMfqHQ2HAF0iNys4hCqM
depends:
    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    tagstream-conduit-0.5.5.3-527b907f2f898027d51ce23ff30849e3
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    xml-conduit-1.3.4-afe40bd27d2aaa75347b019ed922ee43
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.3-25-armv7h.pkg.tar.xz: usr/share/haskell/haskell-authenticate/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.3
id: authenticate-1.3.3-8786f6078b464d3c3f52185ef882a223
key: authe_BfeIAf2U83c0QOtY4UwBay
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
exposed-modules:
    Web.Authenticate.Rpxnow Web.Authenticate.OpenId
    Web.Authenticate.BrowserId Web.Authenticate.OpenId.Providers
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
hs-libraries: HSauthenticate-1.3.3-BfeIAf2U83c0QOtY4UwBay
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    tagstream-conduit-0.5.5.3-450e403db691bac03a51e13c7201c073
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    xml-conduit-1.3.4-233ad2c214e14cf140bab4070afaa144
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
